require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_windowseventlog',
  dscmeta_resource_friendly_name: 'WindowsEventLog',
  dscmeta_resource_name: 'DSC_WindowsEventLog',
  dscmeta_module_name: 'ComputerManagementDsc',
  dscmeta_module_version: '8.3.0',
  docs: 'The DSC WindowsEventLog resource type.
         Automatically generated from version 8.3.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_securitydescriptor: {
      type: 'Optional[String]',
      desc: 'Specifies the given SecurityDescriptor for a specified Windows Event Log',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_maximumsizeinbytes: {
      type: 'Optional[Integer[-9223372036854775808, 9223372036854775807]]',
      desc: 'Specifies the given maximum size in bytes for a specified Windows Event Log',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt64',
      mof_is_embedded: false,
    },
    dsc_logname: {
      type: 'String',
      desc: 'Specifies the given name of a Windows Event Log',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logmode: {
      type: "Optional[Enum['AutoBackup', 'Circular', 'Retain']]",
      desc: 'Specifies the given LogMode for a specified Windows Event Log',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logretentiondays: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: "Specifies the given LogRetentionDays for the Logmode 'AutoBackup'",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_logfilepath: {
      type: 'Optional[String]',
      desc: 'Specifies the given LogFile path of a Windows Event Log',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_isenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies the given state of a Windows Event Log',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
